/* ***** BEGIN LICENSE BLOCK *****
 *    Copyright 2003 Michel Jacobson jacobson@idf.ext.jussieu.fr
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * ***** END LICENSE BLOCK ***** */
package fr.yanntool.util;
/*-----------------------------------------------------------------------*/
import java.awt.*;
import java.io.*;
import javax.swing.*;

/**
* Composant graphique JFrame contenant une console de redirection de la sortie standard, de la sortie erreur ou des deux.
*/
public class ConsoleFrame extends javax.swing.JFrame  implements Console {
    private PrintStream       stdOut = System.out;
    private PrintStream       stdErr = System.err;
    private ConsolePanel      myPanel;
    private boolean           stderr, stdout;

/**
* Construction du composant graphique JFrame contenant la console.
* @param title          titre de la fentre
* @param r          	position et taille de la fentre
* @param stdout         les messages de la sortie standard sont redirigs vers la console (true|false)
* @param stderr         les messages d'erreur sont redirigs vers la console (true|false)
*/
	public ConsoleFrame(String title, Rectangle r, boolean stdout, boolean stderr) {
		super(title);
		setDefaultCloseOperation(JInternalFrame.HIDE_ON_CLOSE);
		this.stdout = stdout;
		this.stderr = stderr;
		myPanel = new ConsolePanel(this);
		Container c = getContentPane();
		c.add(myPanel);
		c.setLayout(new BorderLayout());
		c.add("Center", myPanel);
		setBounds(r);
    }
/**
* Effacer le contenu de la console.
*/
    public void clear() {
		myPanel.clear();
    }
/**
* Affiche la console si elle ne l'est pas.
*/
    public void setVisible() {
		if (!isShowing())
			super.show();
	}
/**
* Redirection.
* @param b          true: redirection vers le composant graphique, false: restitution de l'ancienne affectation.
*/
    public void activate(boolean b) {
		if (b) {
			try {
				if (stdout) {System.setOut(new PrintStream(myPanel.getWriter().asStream(), true, "utf8"));}
				if (stderr) {System.setErr(new PrintStream(myPanel.getWriter().asStream(), true, "utf8"));}
			} catch (Exception e) {
				System.err.println(e.getMessage());
			}
		} else {
			if (stdout) {System.setOut(stdOut);}
			if (stderr) {System.setErr(stdErr);}
		}
    }
    public void removeNotify() {
		if (stdout) {System.setOut(stdOut);}
		if (stderr) {System.setErr(stdErr);}
		super.removeNotify();
    }
}
